@@ -12,7 +12,7 @@ try:
 except:
     pass
 
-version = '0.119'
+version = '0.121'
 
 import re
 import tempfile
@@ -824,6 +824,10 @@ def imread(path):
         img = cv2.imread(os.path.expanduser(path), cv2.IMREAD_COLOR)
     else:
         raise RuntimeError("Image not found: ", path)
+        
+    if img is None:
+        raise RuntimeError("Image is None: ", path)
+        
     return img[:, :, [2, 1, 0]] # This converts the cv2 colors to RGB
 
 def imsread(paths):
@@ -1426,7 +1430,7 @@ def imsToMp4(path, imgs, time_per_image, frame_rate_output_video=30, verbose=0):
     with tempfile.TemporaryDirectory() as d:
         for idx, img in enumerate(imgs):
             imwrite(os.path.join(d, f"img{idx:09d}.png"), img)
-        out = bash(f"cd {d} && ls && ffmpeg -framerate {1/time_per_image} -i img%09d.png -c:v libx264 -r {frame_rate_output_video} -pix_fmt yuv420p {path} -y")
+        out = bash(f'cd {d} && ls && ffmpeg -framerate {1/time_per_image} -i img%09d.png -c:v libx264 -r {frame_rate_output_video} -pix_fmt yuv420p  -vf "reverse,crop=trunc(iw/2)*2:trunc(ih/2)*2" {path} -y')
         if verbose:
             print(out)
 
